@@ -60,7 +60,7 @@ from .exceptions import (
     InvalidAPIKey,
 )
 from .experiment import BaseExperiment
-from .feature_toggles import HTTP_LOGGING, METRICS_HTTP_BATCHING, FeatureToggles
+from .feature_toggles import HTTP_LOGGING, USE_HTTP_MESSAGES, FeatureToggles
 from .heartbeat import HeartbeatThread
 from .json_encoder import NestedEncoder
 from .logging_messages import (
@@ -426,8 +426,8 @@ class Experiment(BaseExperiment):
             file_upload_read_timeout=self.config.get_int(
                 None, "comet.timeout.file_upload"
             ),
-            message_batch_enabled=self.feature_toggles[METRICS_HTTP_BATCHING],
-            message_batch_metric_compress=self.config.get_bool(
+            use_http_messages=self.feature_toggles[USE_HTTP_MESSAGES],
+            message_batch_compress=self.config.get_bool(
                 None, "comet.message_batch.use_compression"
             ),
             message_batch_metric_interval=self.config.get_int(
@@ -436,6 +436,9 @@ class Experiment(BaseExperiment):
             message_batch_metric_max_size=self.config.get_int(
                 None, "comet.message_batch.metric_max_size"
             ),
+            parameters_batch_base_interval=self.config.get_int(
+                None, "comet.message_batch.parameters_interval"
+            ),
         )
 
         # Start streamer thread.
