@@ -18,7 +18,7 @@ from threading import RLock
 
 import six
 
-from ._typing import Any, Callable, Dict, List, Optional, Tuple
+from ._typing import Any, Callable, Dict, List, Optional
 from .messages import BaseMessage, ParameterMessage, RemoteAssetMessage
 from .utils import compact_json_dump, get_time_monotonic
 
@@ -135,7 +135,7 @@ class ParametersBatch(object):
         """
         self.base_interval = base_interval
         self.last_time = 0.0
-        self.items = {}  # type: Dict[str, Tuple[ParameterMessage, int]]
+        self.items = {}  # type: Dict[str, MessageBatchItem]
         # the lock to make sure that ready_to_accept and accept public methods are synchronized
         # and implementation is thread safe
         self.lock = RLock()
@@ -170,11 +170,11 @@ class ParametersBatch(object):
         if message.context is not None:
             name = "%s_%s" % (message.context, name)
 
-        self.items[name] = (message, offset)
+        self.items[name] = MessageBatchItem(message, offset)
         return True
 
     def accept(self, callback, unconditional=False):
-        # type: (Callable[[ParameterMessage, int], None], bool) -> bool
+        # type: (Callable[List[MessageBatchItem], None], bool) -> bool
         """Accepts or ignores provided callback depending on last time this method was invoked and current interval
         between accept events. If time elapsed since last accept exceeds base_interval the provided callback will
         be used to send all collected parameters and batch state will be cleaned.
@@ -231,12 +231,20 @@ class ParametersBatch(object):
             self.base_interval = interval
 
     def _accept(self, callback):
-        # type: (Callable[[ParameterMessage, int], None]) -> None
+        # type: (Callable[List[MessageBatchItem], None]) -> None
         """Accepts the specified callback for all parameters collected so forth"""
-        keys = list(self.items.keys())
-        for key in keys:
-            callback(*self.items[key])  # unpack the tuple with message and offset
-            self.items.pop(key)
+        with self.lock:
+            keys = list(self.items.keys())
+            list_to_sent = list()
+            for key in keys:
+                list_to_sent.append(self.items[key])
+                self.items.pop(key)
+
+        # send batch
+        try:
+            callback(list_to_sent)
+        except Exception:
+            LOGGER.debug("Failed to send parameters batch", exc_info=True)
 
         self.last_time = get_time_monotonic()
 
