@@ -38,7 +38,7 @@ from .compat_utils import json_dump
 from .config import (
     ADDITIONAL_STREAMER_UPLOAD_TIMEOUT,
     DEFAULT_FILE_UPLOAD_READ_TIMEOUT,
-    DEFAULT_PARAMETERS_UPDATE_INTERVAL_SECONDS,
+    DEFAULT_PARAMETERS_BATCH_INTERVAL_SECONDS,
     DEFAULT_STREAMER_MSG_TIMEOUT,
     DEFAULT_WAIT_FOR_FINISH_SLEEP_INTERVAL,
     MESSAGE_BATCH_METRIC_INTERVAL_SECONDS,
@@ -63,6 +63,7 @@ from .logging_messages import (
     METRICS_BATCH_MSG_SENDING_ERROR,
     MODEL_GRAPH_MSG_SENDING_ERROR,
     OS_PACKAGE_MSG_SENDING_ERROR,
+    PARAMETERS_BATCH_MSG_SENDING_ERROR,
     STREAMER_CLOSED_PUT_MESSAGE_FAILED,
     STREAMER_FAILED_TO_PROCESS_ALL_MESSAGES,
     STREAMER_WAIT_FOR_FINISH_FAILED,
@@ -221,9 +222,9 @@ class Streamer(BaseStreamer):
         file_upload_waiting_timeout=ADDITIONAL_STREAMER_UPLOAD_TIMEOUT,
         file_upload_read_timeout=DEFAULT_FILE_UPLOAD_READ_TIMEOUT,
         wait_for_finish_sleep_interval=DEFAULT_WAIT_FOR_FINISH_SLEEP_INTERVAL,
-        parameters_batch_base_interval=DEFAULT_PARAMETERS_UPDATE_INTERVAL_SECONDS,
-        message_batch_enabled=False,
-        message_batch_metric_compress=MESSAGE_BATCH_USE_COMPRESSION_DEFAULT,
+        parameters_batch_base_interval=DEFAULT_PARAMETERS_BATCH_INTERVAL_SECONDS,
+        use_http_messages=False,
+        message_batch_compress=MESSAGE_BATCH_USE_COMPRESSION_DEFAULT,
         message_batch_metric_interval=MESSAGE_BATCH_METRIC_INTERVAL_SECONDS,
         message_batch_metric_max_size=MESSAGE_BATCH_METRIC_MAX_BATCH_SIZE,
     ):
@@ -258,8 +259,8 @@ class Streamer(BaseStreamer):
 
         self.parameters_batch = ParametersBatch(parameters_batch_base_interval)
 
-        self.message_batch_enabled = message_batch_enabled
-        self.message_batch_metric_compress = message_batch_metric_compress
+        self.use_http_messages = use_http_messages
+        self.message_batch_compress = message_batch_compress
         self.message_batch_metrics = MessageBatch(
             base_interval=message_batch_metric_interval,
             max_size=message_batch_metric_max_size,
@@ -267,8 +268,8 @@ class Streamer(BaseStreamer):
 
         LOGGER.debug("Streamer instantiated with ws url %s", self.ws_connection)
         LOGGER.debug(
-            "Message batching enabled: %s, metric batch size: %d, metrics batch interval: %s seconds",
-            message_batch_enabled,
+            "Http messaging enabled: %s, metric batch size: %d, metrics batch interval: %s seconds",
+            use_http_messages,
             message_batch_metric_max_size,
             message_batch_metric_interval,
         )
@@ -303,7 +304,7 @@ class Streamer(BaseStreamer):
                             UploadFileMessage: self._process_upload_message,
                             UploadInMemoryMessage: self._process_upload_in_memory_message,
                             RemoteAssetMessage: self._process_upload_remote_asset_message,
-                            WebSocketMessage: self._process_ws_message,
+                            WebSocketMessage: self._send_ws_message,
                             MetricMessage: self._process_metric_message,
                             ParameterMessage: self._process_parameter_message,
                             OsPackagesMessage: self._process_os_package_message,
@@ -324,11 +325,11 @@ class Streamer(BaseStreamer):
                             handler(message)
 
                 # attempt to send collected parameters
-                if self.parameters_batch.accept(self._send_ws_message):
+                if self.parameters_batch.accept(self._send_parameter_messages_batch):
                     LOGGER.debug("Parameters batch was sent")
 
-                # attempt to send batched metrics
-                if self.message_batch_enabled:
+                # attempt to send batched metrics via HTTP REST
+                if self.use_http_messages:
                     if self.message_batch_metrics.accept(
                         self._send_metric_messages_batch
                     ):
@@ -412,30 +413,50 @@ class Streamer(BaseStreamer):
 
     def _send_metric_messages_batch(self, message_items):
         # type: (List[MessageBatchItem]) -> None
-        try:
-            self.connection.log_metrics_batch(
-                metrics=message_items, compress=self.message_batch_metric_compress
+        self._send_messages_batch(
+            self.connection.log_metrics_batch,
+            message_items=message_items,
+            rest_error_message=METRICS_BATCH_MSG_SENDING_ERROR,
+            general_error_message="Error sending metrics batch (online experiment): %s",
+        )
+
+    def _send_parameter_messages_batch(self, message_items):
+        # type: (List[MessageBatchItem]) -> None
+        if self.use_http_messages:
+            self._send_messages_batch(
+                self.connection.log_parameters_batch,
+                message_items=message_items,
+                rest_error_message=PARAMETERS_BATCH_MSG_SENDING_ERROR,
+                general_error_message="Error sending parameters batch (online experiment): %s",
             )
+        else:
+            # send parameter messages using web socket
+            for item in message_items:
+                self._send_ws_message(message=item.message, offset=item.offset)
+
+    def _send_messages_batch(
+        self,
+        batch_sender_func,
+        message_items,
+        rest_error_message,
+        general_error_message,
+    ):
+        try:
+            batch_sender_func(items=message_items, compress=self.message_batch_compress)
         except CometRestApiException as exc:
             LOGGER.warning(
-                METRICS_BATCH_MSG_SENDING_ERROR,
-                exc.response.status_code,
-                exc.response.content,
+                rest_error_message, exc.response.status_code, exc.response.content
             )
             # report experiment error
             self._report_experiment_error()
-            raise exc
         except Exception as ex:
-            LOGGER.warning(
-                "Error sending metrics batch (online experiment): %s", ex, exc_info=True
-            )
+            LOGGER.warning(general_error_message, ex, exc_info=True)
             # report experiment error
             self._report_experiment_error()
-            raise ex
 
     def _send_ws_message(self, message, offset):
-        # type: (Union[WebSocketMessage, ParameterMessage], int) -> None
-        """The method to be used as callback for parameters batch processing or to send WS messages immediately"""
+        # type: (Union[WebSocketMessage, BaseMessage], int) -> None
+        """To send WS messages immediately"""
         try:
             data = self._serialise_message_for_ws(message=message, offset=offset)
             self.ws_connection.send(data)
@@ -454,14 +475,10 @@ class Streamer(BaseStreamer):
 
     def _process_metric_message(self, message, offset):
         # type: (MetricMessage, int) -> None
-        if self.message_batch_enabled:
+        if self.use_http_messages:
             self.message_batch_metrics.append(message=message, offset=offset)
         else:
-            self._process_ws_message(message, offset)
-
-    def _process_ws_message(self, message, offset):
-        # type: (Union[WebSocketMessage, MetricMessage], int) -> None
-        self._send_ws_message(message, offset)
+            self._send_ws_message(message, offset)
 
     def _serialise_message_for_ws(self, message, offset):
         # type: (BaseMessage, int) -> str
@@ -619,16 +636,14 @@ class Streamer(BaseStreamer):
         # Send all remained parameters from the batch if any
         if not self.parameters_batch.empty():
             if not self.parameters_batch.accept(
-                self._send_ws_message, unconditional=True
+                self._send_parameter_messages_batch, unconditional=True
             ):
                 LOGGER.warning(
                     "Failed to send parameters batch at the end of experiment"
                 )
-                # report experiment error
-                self._report_experiment_error()
 
         # send all remained metrics from the batch if any
-        if self.message_batch_enabled:
+        if self.use_http_messages:
             if not self.message_batch_metrics.empty():
                 if not self.message_batch_metrics.accept(
                     self._send_metric_messages_batch, unconditional=True
