@@ -91,7 +91,7 @@ DEFAULT_INITIAL_DATA_LOGGER_JOIN_TIMEOUT = 5 * 60
 
 DEFAULT_WS_JOIN_TIMEOUT = 30
 
-DEFAULT_PARAMETERS_UPDATE_INTERVAL_SECONDS = 60
+DEFAULT_PARAMETERS_BATCH_INTERVAL_SECONDS = 60
 
 DEFAULT_WAIT_FOR_FINISH_SLEEP_INTERVAL = 15
 
@@ -842,7 +842,7 @@ CONFIG_MAP = {
     "comet.override_feature.sdk_http_logging": {
         "type": bool
     },  # Leave feature toggle default to None
-    "comet.override_feature.use_http_messages": {
+    "comet.override_feature.sdk_use_http_messages": {
         "type": bool
     },  # Leave feature toggle default to None
     "comet.override_feature.sdk_log_env_variables": {
@@ -851,9 +851,6 @@ CONFIG_MAP = {
     "comet.override_feature.artifacts": {
         "type": bool
     },  # Leave feature toggle default to None
-    "comet.override_feature.sdk_metrics_http_batching": {
-        "type": bool
-    },  # Leave feature toggle default to None
     # Experiment log controls:
     "comet.auto_log.cli_arguments": {"type": bool},
     "comet.auto_log.code": {"type": bool},
@@ -918,6 +915,10 @@ CONFIG_MAP = {
         "type": int,
         "default": MESSAGE_BATCH_METRIC_MAX_BATCH_SIZE,
     },
+    "comet.message_batch.parameters_interval": {
+        "type": int,
+        "default": DEFAULT_PARAMETERS_BATCH_INTERVAL_SECONDS,
+    },
 }
 
 
