@@ -35,3 +35,12 @@ CONDA_SPEC_ASSET_TYPE = "conda-specification"
 
 CONDA_INFO_FILE_NAME = "conda-info.yml"
 CONDA_INFO_ASSET_TYPE = "conda-info"
+
+# The experiment status response keys
+STATUS_RESPONSE_IS_ALIVE_BEAT_DURATION_MILLIS = "is_alive_beat_duration_millis"
+STATUS_RESPONSE_GPU_MONITOR_INTERVAL_MILLIS = "gpu_monitor_interval_millis"
+STATUS_RESPONSE_CPU_MONITOR_INTERVAL_MILLIS = "cpu_monitor_interval_millis"
+STATUS_RESPONSE_PARAMETER_UPDATE_INTERVAL_MILLIS = "parameter_update_interval_millis"
+STATUS_RESPONSE_PENDING_RPCS = "pending_rpcs"
+STATUS_RESPONSE_CODE = "code"
+STATUS_RESPONSE_MESSAGE = "msg"
