@@ -27,6 +27,7 @@ import platform
 import socket
 import sys
 
+import pkg_resources
 import requests
 import six
 from six import StringIO
@@ -34,8 +35,16 @@ from six.moves.urllib.parse import urlparse
 
 from ._typing import Any, Dict, List, Optional, Tuple
 from .connection import get_backend_address
+from .logging_messages import (
+    LOG_CONDA_ENV_ERROR,
+    LOG_CONDA_ENV_RETURN_CODE,
+    LOG_CONDA_INFO_ERRORS,
+    LOG_CONDA_INFO_RETURN_CODE,
+    LOG_CONDA_PACKAGES_ERRORS,
+    LOG_CONDA_PACKAGES_RETURN_CODE,
+)
 from .messages import SystemDetailsMessage
-from .utils import get_user
+from .utils import get_comet_version, get_user, subprocess_run_and_check
 
 LOGGER = logging.getLogger(__name__)
 
@@ -120,7 +129,7 @@ def get_env_details():
     }
 
 
-def get_env_details_message(env_blacklist, include_env=False):
+def get_env_details_message(env_blacklist, include_env):
     # type: (List[str], bool) -> SystemDetailsMessage
     if include_env:
         env = get_env_variables(env_blacklist, os.environ)
@@ -147,6 +156,23 @@ def get_env_details_message(env_blacklist, include_env=False):
     )
 
 
+def _get_non_pii_env_details(comet_url):
+    # type: (str) -> Dict[str, Any]
+    """Return environment details without PII, usefull to send to external services like error tracking"""
+
+    return {
+        "pid": get_pid(),
+        "os": get_os(),
+        "os_type": get_os_type(),
+        "python_version_verbose": get_python_version_verbose(),
+        "python_version": get_python_version(),
+        "user": get_user(),
+        "python_exe": sys.executable,
+        "sdk_version": get_comet_version(),
+        "comet_url": comet_url,
+    }
+
+
 def get_caller_file_path():
     # type: () -> Optional[Tuple[str, str]]
     """Returns the module name and file path from the first caller that isn't in the blacklisted
@@ -164,7 +190,7 @@ def get_caller_file_path():
                 continue
 
             filename = module.__file__.rstrip("cd")
-            return (module_name, filename)
+            return module_name, filename
 
     # We didn't find any matching module
     LOGGER.debug("Didn't find any source code module")
@@ -331,3 +357,45 @@ def get_env_cloud_details(timeout=1):
             )
 
     return None
+
+
+def _get_pip_packages():
+    # type: () -> List[str]
+    return sorted(["%s==%s" % (i.key, i.version) for i in pkg_resources.working_set])
+
+
+def _in_conda_environment():
+    # type: () -> bool
+    return os.path.exists(os.path.join(sys.prefix, "conda-meta", "history"))
+
+
+def _in_pydev_console():
+    # type: () -> bool
+    return "PYDEVD_LOAD_VALUES_ASYNC" in os.environ
+
+
+def _get_conda_env():
+    # type: () -> Optional[bytes]
+    args = ["conda", "env", "export"]
+    timeout = 30
+    return subprocess_run_and_check(
+        args, timeout, LOG_CONDA_ENV_ERROR, LOG_CONDA_ENV_RETURN_CODE
+    )
+
+
+def _get_conda_explicit_packages():
+    # type: () -> Optional[bytes]
+    args = ["conda", "list", "--explicit", "--md5"]
+    timeout = 30
+    return subprocess_run_and_check(
+        args, timeout, LOG_CONDA_PACKAGES_ERRORS, LOG_CONDA_PACKAGES_RETURN_CODE
+    )
+
+
+def _get_conda_info():
+    # type: () -> Optional[bytes]
+    args = ["conda", "info"]
+    timeout = 30
+    return subprocess_run_and_check(
+        args, timeout, LOG_CONDA_INFO_ERRORS, LOG_CONDA_INFO_RETURN_CODE
+    )
