@@ -77,6 +77,6 @@ def get_feature_toggle_overrides():
 
 HTTP_LOGGING = "sdk_http_logging"
 
-METRICS_HTTP_BATCHING = "sdk_metrics_http_batching"
+USE_HTTP_MESSAGES = "sdk_use_http_messages"
 
-FT_LIST = [HTTP_LOGGING, METRICS_HTTP_BATCHING]
+FT_LIST = [HTTP_LOGGING, USE_HTTP_MESSAGES]
