@@ -36,7 +36,12 @@ from ._typing import (
     UserText,
     ValidFilePath,
 )
-from .convert_utils import convert_pathlib_path
+from .convert_utils import (
+    convert_pathlib_path,
+    data_to_fp,
+    image_data_to_file_like_object,
+    write_numpy_array_as_wav,
+)
 from .exceptions import AssetIsTooBig
 from .logging_messages import (
     LOG_AUDIO_TOO_BIG,
@@ -47,13 +52,10 @@ from .logging_messages import (
 )
 from .messages import RemoteAssetMessage, UploadFileMessage, UploadInMemoryMessage
 from .utils import (
-    data_to_fp,
     generate_guid,
     get_file_extension,
-    image_data_to_file_like_object,
     parse_remote_uri,
     write_file_like_to_tmp_file,
-    write_numpy_array_as_wav,
 )
 from .validation_utils import validate_metadata
 
@@ -864,30 +866,12 @@ class PreprocessedRemoteAsset(
         self, critical, on_asset_upload, on_failed_asset_upload, experiment_url_params
     ):
         # type: (...) -> RemoteAssetMessage
-        url_params = {
-            "assetId": self.asset_id,
-            "fileName": self.logical_path,
-            "isRemote": True,
-            "overwrite": self.overwrite,
-            "step": self.step,
-        }
-
-        # If the asset type is more specific, include the
-        # asset type as "type" in query parameters:
-        if self.upload_type != "asset":
-            url_params["type"] = self.upload_type
-
-        url_params.update(experiment_url_params)
-
-        return RemoteAssetMessage(
-            self.remote_uri,
-            self.upload_type,
-            url_params,
-            self.metadata,
-            size=self.size,
+        return _remote_asset_to_message(
+            asset=self,
             critical=critical,
             on_asset_upload=on_asset_upload,
             on_failed_asset_upload=on_failed_asset_upload,
+            experiment_url_params=experiment_url_params,
         )
 
 
@@ -895,7 +879,7 @@ def preprocess_remote_asset(
     remote_uri,  # type: Any
     logical_path,  # type: Optional[str]
     overwrite,  # type: bool
-    upload_type,  # type: str
+    upload_type,  # type: Optional[str]
     metadata,  # type: Optional[Dict[str, str]]
     asset_id=None,  # type: Optional[str]
     step=None,  # type: Optional[int]
@@ -934,6 +918,74 @@ def preprocess_remote_asset(
     )
 
 
+class PreprocessedSyncedRemoteAsset(
+    namedtuple(
+        "_PreprocessedSyncedRemoteAsset",
+        [
+            "remote_uri",
+            "overwrite",
+            "upload_type",
+            "metadata",
+            "step",
+            "asset_id",
+            "logical_path",
+            "size",
+            "local_path",  # the path to the downloaded file
+        ],
+    )
+):
+    """Remote asset which was synced against supported cloud storage platforms"""
+
+    __slots__ = ()
+
+    def to_message(
+        self, critical, on_asset_upload, on_failed_asset_upload, experiment_url_params
+    ):
+        # type: (...) -> RemoteAssetMessage
+        return _remote_asset_to_message(
+            asset=self,
+            critical=critical,
+            on_asset_upload=on_asset_upload,
+            on_failed_asset_upload=on_failed_asset_upload,
+            experiment_url_params=experiment_url_params,
+        )
+
+
+def _remote_asset_to_message(
+    asset,  # type: Union[PreprocessedRemoteAsset, PreprocessedSyncedRemoteAsset]
+    critical,  # type: bool
+    on_asset_upload,  # type: Any
+    on_failed_asset_upload,  # type: Any
+    experiment_url_params,  # type: Dict[str, Any]
+):
+    # type: (...) -> RemoteAssetMessage
+    url_params = {
+        "assetId": asset.asset_id,
+        "fileName": asset.logical_path,
+        "isRemote": True,
+        "overwrite": asset.overwrite,
+        "step": asset.step,
+    }
+
+    # If the asset type is more specific, include the
+    # asset type as "type" in query parameters:
+    if asset.upload_type is not None and asset.upload_type != "asset":
+        url_params["type"] = asset.upload_type
+
+    url_params.update(experiment_url_params)
+
+    return RemoteAssetMessage(
+        remote_uri=asset.remote_uri,
+        upload_type=asset.upload_type,
+        additional_params=url_params,
+        metadata=asset.metadata,
+        size=asset.size,
+        critical=critical,
+        on_asset_upload=on_asset_upload,
+        on_failed_asset_upload=on_failed_asset_upload,
+    )
+
+
 class PreprocessedFileAsset(
     namedtuple(
         "_PreprocessedFileAsset",
@@ -1167,7 +1219,10 @@ def preprocess_asset_memory_file(
 
 
 PreprocessedAsset = Union[
-    PreprocessedFileAsset, PreprocessedMemoryFileAsset, PreprocessedRemoteAsset
+    PreprocessedFileAsset,
+    PreprocessedMemoryFileAsset,
+    PreprocessedRemoteAsset,
+    PreprocessedSyncedRemoteAsset,
 ]
 
 
