@@ -30,6 +30,8 @@ import dulwich.porcelain
 import dulwich.repo
 from six.moves.urllib.parse import urlparse
 
+from ._typing import Optional
+
 LOGGER = logging.getLogger(__name__)
 
 
@@ -60,6 +62,10 @@ def get_user(repo):
         return to_utf8(repo.get_config_stack().get("user", "name"))
 
     except KeyError:
+        LOGGER.debug("No Git User configured")
+        return None
+    except Exception:
+        LOGGER.debug("Unexpected error retrieving git user", exc_info=True)
         return None
 
 
@@ -70,6 +76,7 @@ def get_root(repo):
 
     # Check if the repository is empty
     if len(repo.get_refs()) == 0:
+        LOGGER.debug("Repository is empty, cannot get root")
         return None
 
     # Get walker needs at least the HEAD ref to be present
@@ -97,6 +104,10 @@ def get_branch(repo):
     for ref in refnames:
         if ref != b"HEAD":
             return to_utf8(ref)
+    else:
+        # This shouldn't happens, a repository without a HEAD reference is not recognized by Git
+        # itself as a repository
+        LOGGER.debug("Didn't find the HEAD ref")
 
 
 def get_git_commit(repo):
@@ -105,14 +116,15 @@ def get_git_commit(repo):
         return to_utf8(repo.head())
 
     except KeyError:
+        LOGGER.debug("Failed to get current git commit", exc_info=True)
         return None
 
 
 def git_status(repo):
+    # Monkey-patch a dulwich method, see
+    # https://github.com/dulwich/dulwich/pull/601 for an explanation why
+    original = dulwich.porcelain.path_to_tree_path
     try:
-        # Monkey-patch a dulwich method, see
-        # https://github.com/dulwich/dulwich/pull/601 for an explanation why
-        original = dulwich.porcelain.path_to_tree_path
         dulwich.porcelain.path_to_tree_path = _patched_path_to_tree_path
 
         status = dulwich.porcelain.status(repo)
@@ -137,6 +149,7 @@ def get_origin_url(repo):
         return to_utf8(repo_config.get((b"remote", b"origin"), "url"))
 
     except KeyError:
+        LOGGER.debug("Failed to get GIT origin url", exc_info=True)
         return None
 
 
@@ -279,22 +292,8 @@ def get_git_patch(repo, unstaged=True):
     return diff_result
 
 
-def find_git_patch(path):
-    # First find the repo
-    repo = find_git_repo(path)
-
-    if not repo:
-        return None
-
-    patch = get_git_patch(repo)
-
-    # Close the repo to close all opened fds
-    repo.close()
-
-    return patch
-
-
 def find_git_repo(repo_path):
+    # type: (str) -> Optional[dulwich.repo.Repo]
     # Early-exit if repo_path is repo root
     try:
         return dulwich.repo.Repo(repo_path)
@@ -317,13 +316,7 @@ def find_git_repo(repo_path):
             pass
 
 
-def get_git_metadata(path):
-    # First find the repo
-    repo = find_git_repo(path)
-
-    if not repo:
-        return None
-
+def get_git_metadata(repo):
     origin = get_origin_url(repo)
     repo_name = get_repo_name(origin)
 
@@ -337,7 +330,4 @@ def get_git_metadata(path):
         "repo_name": repo_name,
     }
 
-    # Close the repo to close all opened fds
-    repo.close()
-
     return data
