@@ -22,7 +22,7 @@ import logging
 import threading
 import time
 
-from comet_ml.utils import to_utf8
+from comet_ml.utils import metric_name, to_utf8
 
 try:
     import pynvml
@@ -244,16 +244,21 @@ def is_gpu_details_available():
 
 
 class GPULoggingThread(threading.Thread):
-    def __init__(self, initial_interval, callback):
+    def __init__(self, initial_interval, callback, metrics_prefix=None):
         super(GPULoggingThread, self).__init__()
         self.daemon = True
         self.interval = initial_interval
         self.callback = callback
         self.last_run = 0.0
+        self.metrics_prefix = metrics_prefix
 
         self.closed = False
 
-        LOGGER.debug("GPUThread create with %ds interval", initial_interval)
+        LOGGER.debug(
+            "GPUThread create with %ds interval, metrics prefix: %s",
+            initial_interval,
+            metrics_prefix,
+        )
 
     def run(self):
         while not self.closed:
@@ -287,10 +292,13 @@ class GPULoggingThread(threading.Thread):
         self.closed = True
 
 
-def convert_gpu_details_to_metrics(gpu_details):
+def convert_gpu_details_to_metrics(gpu_details, prefix=None):
     metrics = []
     for i, gpu in enumerate(gpu_details):
         for key, value in gpu.items():
-            metric = {"name": "sys.gpu.%d.%s" % (i, key), "value": value}
+            metric = {
+                "name": metric_name("sys.gpu.%d.%s" % (i, key), prefix=prefix),
+                "value": value,
+            }
             metrics.append(metric)
     return metrics
