@@ -16,8 +16,8 @@
 import logging
 
 from .._typing import Any, Dict, List, Tuple
+from ..data_structure import Histogram
 from ..monkey_patching import check_module
-from ..utils import Histogram
 
 LOGGER = logging.getLogger(__name__)
 
@@ -143,8 +143,16 @@ def summary_image_logger(experiment, original, value, *args, **kwargs):
     """
     try:
         name, data, step = get_args(*args, **kwargs)
-        for image in data:
-            experiment.log_image(image, step=step)
+        if len(data) == 1:
+            # single image - logging without suffix
+            experiment.log_image(data[0], name=name, step=step)
+        else:
+            # multiple images - logging prefixed by image index if appropriate
+            full_name = None
+            for i, image in enumerate(data):
+                if name is not None:
+                    full_name = full_image_name(prefix=name, index=i)
+                experiment.log_image(image, name=full_name, step=step)
     except Exception:
         LOGGER.error("Failed to extract from tensorflow.summary.image()", exc_info=True)
 
@@ -168,18 +176,23 @@ def summary_histogram_3d_logger(experiment, original, value, *args, **kwargs):
         )
 
 
+def full_image_name(prefix, index):
+    # type: (str, int) -> str
+    return "%s_%d" % (prefix, index)
+
+
 def get_args(name, data, step=None, **kwargs):
     """
     Wrapper to parse args
     """
-    return (name, data, step)
+    return name, data, step
 
 
 def get_audio_args(name, data, sample_rate=None, step=None, **kwargs):
     """
     Wrapper to parse args
     """
-    return (name, data, step, sample_rate)
+    return name, data, step, sample_rate
 
 
 class ContextHolder:
