@@ -224,7 +224,11 @@ LOG_DATASET_ERROR = "Failed to create dataset hash"
 
 OS_PACKAGE_MSG_SENDING_ERROR = "Error sending os_packages message, got %d %r"
 
-METRICS_BATCH_MSG_SENDING_ERROR = "Error sending metrics batch message, got %d %r"
+METRICS_BATCH_MSG_SENDING_ERROR = "Failed to send metrics batch message, got %d %r"
+
+PARAMETERS_BATCH_MSG_SENDING_ERROR = (
+    "Failed to send parameters batch message, got %d %r"
+)
 
 MODEL_GRAPH_MSG_SENDING_ERROR = "Error sending model graph message, got %d %r"
 
