@@ -46,7 +46,7 @@ from ._reporting import (
     OFFLINE_INVALID_UPLOAD_MSG,
     OFFLINE_INVALID_WS_MSG,
 )
-from ._typing import Any, Dict, List, Optional, Tuple, Union
+from ._typing import Any, Dict, List, Optional, Tuple
 from .batch_utils import MessageBatch, MessageBatchItem, ParametersBatch
 from .comet import OfflineStreamer, format_url
 from .compat_utils import json_dump
@@ -88,7 +88,7 @@ from .exceptions import (
     OfflineExperimentUploadFailed,
 )
 from .experiment import BaseExperiment
-from .feature_toggles import METRICS_HTTP_BATCHING, FeatureToggles
+from .feature_toggles import USE_HTTP_MESSAGES, FeatureToggles
 from .logging_messages import (
     CLOUD_DETAILS_MSG_SENDING_ERROR,
     FILE_UPLOADS_PROMPT,
@@ -123,9 +123,11 @@ from .logging_messages import (
     OFFLINE_UPLOADING_EXPERIMENT_FILE_PROMPT,
     OFFLINE_UPLOADS_FAILED_DUE_TIMEOUT,
     OS_PACKAGE_MSG_SENDING_ERROR,
+    PARAMETERS_BATCH_MSG_SENDING_ERROR,
     WAITING_DATA_UPLOADED,
 )
 from .messages import (
+    BaseMessage,
     CloudDetailsMessage,
     FileNameMessage,
     MetricMessage,
@@ -626,7 +628,7 @@ class OfflineSender(object):
         file_upload_waiting_timeout=ADDITIONAL_STREAMER_UPLOAD_TIMEOUT,  # type: int
         override_workspace=None,  # type: Optional[str]
         override_project_name=None,  # type: Optional[str]
-        message_batch_enabled=False,
+        use_http_messages=False,
         message_batch_metric_interval=MESSAGE_BATCH_METRIC_INTERVAL_SECONDS,
         message_batch_metric_max_size=MESSAGE_BATCH_METRIC_MAX_BATCH_SIZE,
         message_batch_metric_compress=MESSAGE_BATCH_USE_COMPRESSION_DEFAULT,
@@ -691,7 +693,7 @@ class OfflineSender(object):
 
         self.raise_validation_error_for_tests = raise_validation_error_for_tests
 
-        self.message_batch_enabled = message_batch_enabled
+        self.use_http_messages = use_http_messages
         self.message_batch_metrics = MessageBatch(
             base_interval=message_batch_metric_interval,
             max_size=message_batch_metric_max_size,
@@ -718,8 +720,8 @@ class OfflineSender(object):
         self._send_start_ends_time()
 
         LOGGER.debug(
-            "Offline message batching enabled: %s, metric batch size: %d, metrics batch interval: %s seconds",
-            self.message_batch_enabled,
+            "Offline http sending enabled: %s, metric batch size: %d, metrics batch interval: %s seconds",
+            self.use_http_messages,
             self.message_batch_metrics.max_size,
             self.message_batch_metrics.base_interval,
         )
@@ -917,7 +919,7 @@ class OfflineSender(object):
         self.feature_toggles = FeatureToggles(
             run_id_results.feature_toggles, self.config
         )
-        self.message_batch_enabled = self.feature_toggles[METRICS_HTTP_BATCHING]
+        self.use_http_messages = self.feature_toggles[USE_HTTP_MESSAGES]
 
         # Send tags if present
         if self.tags:
@@ -1008,7 +1010,7 @@ class OfflineSender(object):
 
         # Then send the sampled metrics
         samples = sampler.get_samples()
-        if self.message_batch_enabled:
+        if self.use_http_messages:
             # send all collected metric samples as batch(-es)
             self._send_sampled_metrics_batch(samples)
         else:
@@ -1020,7 +1022,9 @@ class OfflineSender(object):
                     LOGGER.warning("Error processing metric", exc_info=True)
 
         # And the batched hyper-parameters
-        if parameter_batch.accept(self._send_ws_message, unconditional=True):
+        if parameter_batch.accept(
+            self._send_parameter_messages_batch, unconditional=True
+        ):
             LOGGER.debug("Parameters batch was sent")
 
         LOGGER.debug("Done sending %d messages", i)
@@ -1047,31 +1051,52 @@ class OfflineSender(object):
             self._send_metric_messages_batch, unconditional=True
         )
 
+    def _send_parameter_messages_batch(self, message_items):
+        # type: (List[MessageBatchItem]) -> None
+        """Attempts tto send batch of parameters"""
+        if self.use_http_messages:
+            self._send_messages_batch(
+                self.connection.log_parameters_batch,
+                message_items=message_items,
+                rest_error_message=PARAMETERS_BATCH_MSG_SENDING_ERROR,
+                general_error_message="Error sending parameters batch (offline experiment): %s",
+            )
+        else:
+            # send parameter messages using web socket
+            for item in message_items:
+                self._send_ws_message(message=item.message, offset=item.offset)
+
     def _send_metric_messages_batch(self, message_items):
         # type: (List[MessageBatchItem]) -> None
         """Attempts to send batch of metrics."""
+        self._send_messages_batch(
+            self.connection.log_metrics_batch,
+            message_items=message_items,
+            rest_error_message=METRICS_BATCH_MSG_SENDING_ERROR,
+            general_error_message="Error sending metrics batch (offline experiment): %s",
+        )
+
+    def _send_messages_batch(
+        self,
+        batch_sender_func,
+        message_items,
+        rest_error_message,
+        general_error_message,
+    ):
         try:
-            self.connection.log_metrics_batch(
-                metrics=message_items, compress=self.message_batch_metric_compress
+            batch_sender_func(
+                items=message_items, compress=self.message_batch_metric_compress
             )
         except CometRestApiException as exc:
             LOGGER.warning(
-                METRICS_BATCH_MSG_SENDING_ERROR,
-                exc.response.status_code,
-                exc.response.content,
+                rest_error_message, exc.response.status_code, exc.response.content
             )
             # report experiment error
             self._report_experiment_error()
-            raise exc
         except Exception as ex:
-            LOGGER.warning(
-                "Error sending metrics batch (offline experiment): %s",
-                ex,
-                exc_info=True,
-            )
+            LOGGER.warning(general_error_message, ex, exc_info=True)
             # report experiment error
             self._report_experiment_error()
-            raise ex
 
     def _validate_msg(
         self,
@@ -1120,7 +1145,7 @@ class OfflineSender(object):
             self._report_experiment_error()
 
     def _send_ws_message(self, message, offset=None):
-        # type: (Union[ParameterMessage, MetricMessage], Optional[int]) -> None
+        # type: (BaseMessage, Optional[int]) -> None
         """The method to be used as callback for parameters batch processing or to send WS messages immediately"""
         try:
             message_dict = message._non_null_dict()
