@@ -44,6 +44,16 @@ def get_ws_msg_validator(allow_additional_properties=True):
     return get_validator("offline-ws-msg.schema.json", allow_additional_properties)
 
 
+def get_parameter_msg_validator(allow_additional_properties=True):
+    return get_validator(
+        "offline-parameter-msg.schema.json", allow_additional_properties
+    )
+
+
+def get_metric_msg_validator(allow_additional_properties=True):
+    return get_validator("offline-metric-msg.schema.json", allow_additional_properties)
+
+
 def get_os_packages_msg_validator(allow_additional_properties=False):
     return get_validator(
         "offline-os-packages-msg.schema.json", allow_additional_properties
@@ -82,3 +92,9 @@ def get_3d_boxes_validator(allow_additional_properties=False):
     return get_validator(
         "3d-points-bounding-box.schema.json", allow_additional_properties
     )
+
+
+def get_file_name_msg_validator(allow_additional_properties=False):
+    return get_validator(
+        "offline-file-name-msg.schema.json", allow_additional_properties
+    )
