@@ -21,24 +21,28 @@ import sys
 
 from comet_ml._typing import Any, List, Optional
 from comet_ml.config import (
+    Config,
     ConfigDictEnv,
     ConfigEnvFileEnv,
     ConfigIniEnv,
     ConfigOSEnv,
     get_config,
+    get_ws_url,
 )
 from comet_ml.connection import (
     _comet_version,
-    get_http_proxy,
+    _debug_proxy_for_http,
+    _debug_proxy_for_ws,
+    get_and_format_proxy_for_ws,
     get_http_session,
+    get_optimizer_address,
     get_root_url,
     get_run_id_url,
+    get_websocket_sslopt,
     sanitize_url,
     url_join,
-    urlparse,
-    urlunparse,
 )
-from comet_ml.utils import local_timestamp
+from comet_ml.utils import local_timestamp, urlparse, urlunparse
 
 import six.moves.urllib_request as request
 import websocket
@@ -76,19 +80,26 @@ def activate_debug():
     websocket.enableTrace(True)
 
 
-def check_ws_connection(websocket_url, debug):
-    # type: (str, bool) -> bool
+def check_ws_connection(websocket_url, debug, verify_tls):
+    # type: (str, bool, bool) -> bool
 
     try:
-        http_proxy_host, http_proxy_port, http_proxy_auth, proxy_type = get_http_proxy(
-            websocket_url
-        )
+        (
+            http_proxy_host,
+            http_proxy_port,
+            http_proxy_auth,
+            proxy_type,
+        ) = get_and_format_proxy_for_ws(websocket_url)
+
+        sslopt = get_websocket_sslopt(verify_tls)
+
         ws = websocket.create_connection(
             websocket_url,
             http_proxy_host=http_proxy_host,
             http_proxy_port=http_proxy_port,
             http_proxy_auth=http_proxy_auth,
             proxy_type=proxy_type,
+            sslopt=sslopt,
         )
 
         if debug:
@@ -122,10 +133,10 @@ def get_default_ws_url(clientlib_address):
     return urlunparse((ws_scheme, ws_host, ws_path, None, None, None))
 
 
-def check_server_connection(server_address):
+def check_server_connection(server_address, verify_tls):
     url = get_run_id_url(server_address)
     try:
-        with get_http_session() as session:
+        with get_http_session(verify_tls=verify_tls) as session:
             payload = {
                 "apiKey": "XXX",
                 "local_timestamp": local_timestamp(),
@@ -143,10 +154,10 @@ def check_server_connection(server_address):
         return False
 
 
-def check_rest_api_connection(rest_api_url):
+def check_rest_api_connection(rest_api_url, verify_tls):
     url = url_join(rest_api_url, "account-details")
     try:
-        with get_http_session() as session:
+        with get_http_session(verify_tls=verify_tls) as session:
             session.get(url)
             return True
     except Exception:
@@ -154,10 +165,10 @@ def check_rest_api_connection(rest_api_url):
         return False
 
 
-def check_optimizer_connection(optimizer_url):
+def check_optimizer_connection(optimizer_url, verify_tls):
     url = url_join(optimizer_url, "spec")
     try:
-        with get_http_session() as session:
+        with get_http_session(verify_tls=verify_tls) as session:
             params = {"algorithmName": "bayes"}
             session.get(url, params=params)
             return True
@@ -187,6 +198,7 @@ def check(args, rest=None):
         activate_debug()
 
     config = get_config()
+    verify_tls = config.get_bool(None, "comet.internal.check_tls_certificate")
 
     LOGGER.info("Comet Check")
     LOGGER.info("=" * DELIMITERS_LENGTH)
@@ -206,7 +218,7 @@ def check(args, rest=None):
     else:
         LOGGER.info("Server address is the default one")
     print("")
-    server_connected = check_server_connection(server_address)
+    server_connected = check_server_connection(server_address, verify_tls)
     print("")
     if server_connected:
         LOGGER.info("Server connection is ok")
@@ -228,7 +240,7 @@ def check(args, rest=None):
     else:
         LOGGER.info("Rest API address is the default one")
     print("")
-    rest_api_connected = check_rest_api_connection(rest_api_url)
+    rest_api_connected = check_rest_api_connection(rest_api_url, verify_tls)
     print("")
     if rest_api_connected:
         LOGGER.info("REST API connection is ok")
@@ -240,7 +252,7 @@ def check(args, rest=None):
     LOGGER.info("Checking connectivity to Websocket Server")
     LOGGER.info("=" * DELIMITERS_LENGTH)
 
-    websocket_url = config["comet.ws_url_override"]
+    websocket_url = get_ws_url(None, config)
     if websocket_url is None:
         websocket_url = get_default_ws_url(server_address)
         LOGGER.warning(
@@ -261,7 +273,7 @@ def check(args, rest=None):
     if websocket_url_config_origin:
         LOGGER.info("WS address was configured in %s", websocket_url_config_origin)
     print("")
-    ws_connected = check_ws_connection(websocket_url, args.debug)
+    ws_connected = check_ws_connection(websocket_url, args.debug, verify_tls)
     print("")
     if ws_connected:
         LOGGER.info("Websocket connection is ok")
@@ -273,7 +285,7 @@ def check(args, rest=None):
     LOGGER.info("Checking connectivity to Optimizer Server")
     LOGGER.info("=" * DELIMITERS_LENGTH)
 
-    optimizer_url = sanitize_url(config["comet.optimizer_url"])
+    optimizer_url = get_optimizer_address(config)
     optimizer_url_config_origin = config_source(
         config.get_config_origin("comet.optimizer_url")
     )
@@ -288,7 +300,7 @@ def check(args, rest=None):
     else:
         LOGGER.info("Optimizer address is the default one")
     print("")
-    optimizer_connected = check_optimizer_connection(optimizer_url)
+    optimizer_connected = check_optimizer_connection(optimizer_url, verify_tls)
     print("")
     if optimizer_connected:
         LOGGER.info("Optimizer connection is ok")
@@ -300,7 +312,10 @@ def check(args, rest=None):
     log_system_info()
     log_modules_info(["requests", "urllib3", "websocket"])
     log_system_proxies_info()
-    log_proxies_info_for_urls([server_address, rest_api_url, websocket_url])
+    log_proxies_info_for_urls(
+        http_urls=[server_address, rest_api_url], ws_urls=[websocket_url]
+    )
+    log_tls_verification(config)
     log_ca_bundles_paths()
 
     print("")
@@ -361,30 +376,47 @@ def log_system_proxies_info():
     LOGGER.info("-" * DELIMITERS_LENGTH)
 
 
-def log_proxies_info_for_urls(urls):
-    # type: (List[str]) -> None
-    """Collects and logs information about proxies which proxy access to the specified list of URLs"""
-    for url in urls:
+def log_proxies_info_for_urls(http_urls, ws_urls):
+    # type: (List[str], List[str]) -> None
+    # Log HTTP proxy info
+    for url in http_urls:
         try:
-            (
-                http_proxy_host,
-                http_proxy_port,
-                http_proxy_auth,
-                proxy_type,
-            ) = get_http_proxy(url)
-            if http_proxy_host:
-                LOGGER.info(
-                    "%s -> %s://%s:%s",
-                    url,
-                    proxy_type,
-                    http_proxy_host,
-                    http_proxy_port,
-                )
-            else:
-                LOGGER.info("%s -> NO PROXY", url)
+            proxy = _debug_proxy_for_http(url)
+            log_proxy_info_for_url(url, proxy)
         except Exception:
             LOGGER.error("Failed to check proxy for URL: %s", url, exc_info=True)
 
+    for ws_url in ws_urls:
+        try:
+            proxy = _debug_proxy_for_ws(ws_url)
+            log_proxy_info_for_url(ws_url, proxy)
+        except Exception:
+            LOGGER.error("Failed to check proxy for URL: %s", ws_url, exc_info=True)
+
+
+def log_proxy_info_for_url(url, proxy):
+    # type: (str, Optional[str]) -> None
+    """Collects and logs information about proxies which proxy access to the specified list of URLs"""
+    if proxy:
+        LOGGER.info(
+            "%s -> %s",
+            url,
+            proxy,
+        )
+    else:
+        LOGGER.info("%s -> NO PROXY", url)
+
+
+def log_tls_verification(config):
+    # type: (Config) -> None
+    LOGGER.info("-" * DELIMITERS_LENGTH)
+    tls_verification = config.get_bool(None, "comet.internal.check_tls_certificate")
+
+    if tls_verification:
+        LOGGER.info("TLS Certificate verification is ENABLED")
+    else:
+        LOGGER.info("TLS Certification verification is DISABLED")
+
 
 def log_ca_bundles_paths():
     LOGGER.info("=" * DELIMITERS_LENGTH)
