@@ -259,7 +259,9 @@ def get_user():
         # We are in a system with no user, like Docker container with custom UID
         return "unknown"
     except Exception:
-        LOGGER.debug("Unkown exception getting the user from the system", exc_info=True)
+        LOGGER.debug(
+            "Unknown exception getting the user from the system", exc_info=True
+        )
         return "unknown"
 
 
